@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_es.paginator import (
     DescribeReservedElasticsearchInstanceOfferingsPaginator,
@@ -66,15 +66,15 @@ __all__ = ("ElasticsearchServiceClient",)
 
 
 class Exceptions:
-    BaseException: Boto3ClientError
-    ClientError: Boto3ClientError
-    DisabledOperationException: Boto3ClientError
-    InternalException: Boto3ClientError
-    InvalidTypeException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    ResourceAlreadyExistsException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ValidationException: Boto3ClientError
+    BaseException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    DisabledOperationException: Type[Boto3ClientError]
+    InternalException: Type[Boto3ClientError]
+    InvalidTypeException: Type[Boto3ClientError]
+    LimitExceededException: Type[Boto3ClientError]
+    ResourceAlreadyExistsException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
 
 
 class ElasticsearchServiceClient:
